***************
Getting Started
***************

This 'Getting Started' guide aims to get you using Project
productively as quickly as possible.

Detailed documentation is contained in the `User Guide
<../user_guide/index.html>`_; we link to the user guide from the
appropriate sections of this guide.

To see what can be done with Project, see our `Gallery
<../gallery/index.html>`_ of interesting examples.

We recommend you proceed through the following in order; it should
take around 1 hour in total.

* `Introduction <1-Introduction.html>`_
   What is Project?

* `Installation <2-Installation.html>`_
   Install Project to run through this guide interactively.

* `Tabular Datasets <3-Tabular_Datasets.html>`_
   Introduction to working with tabular data.

* `Gridded Datasets <4-Gridded_Datasets.html>`_
   Introduction to working with tabular data.
   
* Etc...


.. toctree::
    :titlesonly:
    :hidden:
    :maxdepth: 2

    Introduction <1-Introduction>
    Installation <2-Installation>
    Tabular Datasets <3-Tabular_Datasets>
    Gridded Datasets <4-Gridded_Datasets>
